@@ -78,13 +78,14 @@ mpc_set_orientation (XfcePanelPlugin * plugin, GtkOrientation orientation, t_mpc
 static gboolean
 mpc_set_size (XfcePanelPlugin * plugin, int size, t_mpc * mpc)
 {
+   int border_width = (size > 26 && mpc->show_frame ? 1 : 0);
 #ifdef HAS_PANEL_49
     size /= xfce_panel_plugin_get_nrows (plugin);
 #endif
 
    DBG ("size=%d",size);
-   gtk_container_set_border_width (GTK_CONTAINER (mpc->frame), (size > 26 && mpc->show_frame ? 2 : 0));
-
+   gtk_container_set_border_width (GTK_CONTAINER (mpc->frame), border_width);
+   size -= 2 * border_width;
    gtk_widget_set_size_request (GTK_WIDGET (mpc->next), size, size);
    gtk_widget_set_size_request (GTK_WIDGET (mpc->prev), size, size);
    gtk_widget_set_size_request (GTK_WIDGET (mpc->stop), size, size);
@@ -248,7 +249,7 @@ mpc_dialog_show_frame_toggled (GtkWidget *w, t_mpc_dialog *dialog)
    size = xfce_panel_plugin_get_size(mpc->plugin);
    mpc->show_frame = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->checkbox_frame));
    gtk_frame_set_shadow_type (GTK_FRAME (mpc->frame), (mpc->show_frame) ? GTK_SHADOW_IN : GTK_SHADOW_NONE);
-   gtk_container_set_border_width (GTK_CONTAINER (mpc->frame), (size > 26 && mpc->show_frame ? 2 : 0));
+   mpc_set_size(mpc->plugin, size, mpc);
 }
 
 static void
